@@ -135,6 +135,8 @@ class APIClient:
             if 'icp' == wml_credentials[u'instance_id'].lower() or 'openshift' == wml_credentials[
                 u'instance_id'].lower() or 'wml_local' == wml_credentials[u'instance_id'].lower():
                 self.ICP = True
+                import requests
+                requests.packages.urllib3.disable_warnings()
                 os.environ["DEPLOYMENT_PLATFORM"] = "private"
                 ##Condition for CAMS related changes to take effect (Might change)
                 if 'version' not in wml_credentials:
