@@ -580,14 +580,14 @@ class BaseDeployment(ABC):
                            "assetType": "wml_model",
                            "assetDescription": "Model promoted by ibm_wml client"}
         promote_href = self._source_workspace.wml_client.service_instance._href_definitions.promote_asset_href(model_id)
-
         response = requests.post(
             promote_href,
             headers=self._source_workspace.wml_client._get_headers(),
             json=promote_payload,
             verify=False
         )
-        promotion_details = self._source_workspace.wml_client.repository._handle_response(200, u'promote model asset', response)
+        promotion_details = self._source_workspace.wml_client.repository._handle_response(200, u'promote model asset',
+                                                                                          response)
 
         try:
             promoted_model_id = promotion_details['promotedAsset']['asset_id']
