@@ -369,14 +369,12 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                     raise InvalidDataAsset(
                         reason="Please specify Data Asset pointing to connection e.g. COS as an output.")
 
-                data_asset_details = self._workspace.wml_client.data_assets.store(
-                    {'connection_id': connection_id,
-                     "name": 'Default autoai output',
-                     'data_content_name': 'default_autoai_out'
-                     })
-
                 training_results_reference = DataConnection(
-                    data_asset_id=data_asset_details['metadata']['guid'])
+                    connection_asset_id=connection_id,
+                    location=S3Location(
+                        bucket=training_data_reference[0].location._get_bucket(self._workspace.wml_client),
+                        path="default_autoai_out")
+                )
 
             else:
                 location = FSLocation()
@@ -756,3 +754,4 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         else:
             raise MissingDataPreprocessingStep(
                 reason="Cannot get preprocessed pipeline as preprocessing step was not performed.")
+
