@@ -15,4 +15,4 @@
 from ibm_watson_machine_learning.helpers.connections.connections import (
     DataConnection, S3Connection, S3Location, FSLocation, AssetLocation, CP4DAssetLocation,
     WMLSAssetLocation, CloudAssetLocation, WSDAssetLocation, DeploymentOutputAssetLocation,
-    NFSConnection, NFSLocation)
+    NFSConnection, NFSLocation, ConnectionAsset, ConnectionAssetLocation, DatabaseLocation)
