@@ -159,7 +159,7 @@ class BaseDataConnection(ABC):
                 json_content = json.loads(buffer.getvalue().decode('utf-8'))
 
         elif self.type == DataConnectionTypes.CA:
-            if os.environ.get('USER_ACCESS_TOKEN') is None and self._check_if_connection_asset_is_s3():
+            if self._check_if_connection_asset_is_s3():
                 cos_client = self._init_cos_client()
 
                 try:
@@ -183,125 +183,133 @@ class BaseDataConnection(ABC):
         return json_content
 
     def _check_if_connection_asset_is_s3(self) -> bool:
-        if self.type == 'data_asset':
-            if self.connection is not None:
-                items = self.connection.href.split('/')
-
-            else:
-                items = self.location.href.split('/')
-            _id = items[-1].split('?')[0]
-
-            if self._wml_client is not None:
-                data_asset_details = self._wml_client.data_assets.get_details(_id)
-
-                attachment_id = data_asset_details['metadata']['attachment_id']
-                if not self._wml_client.ICP and not self._wml_client.WSD:
-                    response = requests.get(
-                        self._wml_client.service_instance._href_definitions.get_attachment_href(_id, attachment_id),
-                        params=self._wml_client.data_assets._client._params(),
-                        headers=self._wml_client.data_assets._client._get_headers())
-                else:
-                    response = requests.get(
-                        self._wml_client.service_instance._href_definitions.get_attachment_href(_id, attachment_id),
-                        params=self._wml_client.data_assets._client._params(),
-                        headers=self._wml_client.data_assets._client._get_headers(),
-                        verify=False)
-
-                if response.status_code == 200:
-                    attachment_details = response.json()
-                    if 'connection_id' not in attachment_details:
-                        return False
-
-                    connection_details = self._wml_client.connections.get_details(attachment_details['connection_id'])
+        try:
+            if self.type == 'data_asset':
+                if self.connection is not None:
+                    items = self.connection.href.split('/')
 
                 else:
-                    raise WMLClientError("Failed while downloading the attachment " + attachment_id)
+                    items = self.location.href.split('/')
+                _id = items[-1].split('?')[0]
 
-            else:
-                try:
-                    from project_lib import Project
-                    project = Project.access()
+                if self._wml_client is not None:
+                    data_asset_details = self._wml_client.data_assets.get_details(_id)
+
+                    attachment_id = data_asset_details['metadata']['attachment_id']
+                    if not self._wml_client.ICP and not self._wml_client.WSD:
+                        response = requests.get(
+                            self._wml_client.service_instance._href_definitions.get_attachment_href(_id, attachment_id),
+                            params=self._wml_client.data_assets._client._params(),
+                            headers=self._wml_client.data_assets._client._get_headers())
+                    else:
+                        response = requests.get(
+                            self._wml_client.service_instance._href_definitions.get_attachment_href(_id, attachment_id),
+                            params=self._wml_client.data_assets._client._params(),
+                            headers=self._wml_client.data_assets._client._get_headers(),
+                            verify=False)
+
+                    if response.status_code == 200:
+                        attachment_details = response.json()
+                        if 'connection_id' not in attachment_details:
+                            return False
+
+                        connection_details = self._wml_client.connections.get_details(attachment_details['connection_id'])
+
+                    else:
+                        raise WMLClientError("Failed while downloading the attachment " + attachment_id)
+
+                else:
                     try:
-                        connection_details = project.get_connected_data(_id)
+                        from project_lib import Project
+                        project = Project.access()
+                        try:
+                            connection_details = project.get_connected_data(_id)
 
-                    except RuntimeError:    # when data asset is normal not s3 or database
-                        return False
+                        except RuntimeError:    # when data asset is normal not s3 or database
+                            return False
 
-                    attachment_details = {'connection_path': connection_details.get('datapath')}
+                        attachment_details = {'connection_path': connection_details.get('datapath')}
 
-                except ModuleNotFoundError:
-                    raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
+                    except ModuleNotFoundError:
+                        raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
 
-        elif self.type == 'connection_asset':
-            if self._wml_client is not None:
-                connection_details = self._wml_client.connections.get_details(self.connection.id)
+            elif self.type == 'connection_asset':
+                if self._wml_client is not None:
+                    connection_details = self._wml_client.connections.get_details(self.connection.id)
+
+                else:
+                    try:
+                        from project_lib import Project
+                        project = Project.access()
+                        connection_details = project.get_connection(self.connection.id)
+
+                    except ModuleNotFoundError:
+                        raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
+
+            elif self.type == 's3' or self.type == 'fs':
+                return False
 
             else:
-                try:
-                    from project_lib import Project
-                    project = Project.access()
-                    connection_details = project.get_connection(self.connection.id)
+                raise WrongAssetType(asset_type=self.type)
 
-                except ModuleNotFoundError:
-                    raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
+            # Note: Check with project libs if connection points to S3
+            if self._wml_client is not None:
+                if (connection_details['entity']['datasource_type'] ==
+                        self._wml_client.connections.get_datasource_type_uid_by_name('bluemixcloudobjectstorage') or
+                        connection_details['entity']['datasource_type'] == 'bluemixcloudobjectstorage'):
 
-        elif self.type == 's3' or self.type == 'fs':
-            return False
+                    cos_type = True
 
-        else:
-            raise WrongAssetType(asset_type=self.type)
-
-        # Note: Check with project libs if connection points to S3
-        if self._wml_client is not None:
-            if (connection_details['entity']['datasource_type'] ==
-                    self._wml_client.connections.get_datasource_type_uid_by_name('bluemixcloudobjectstorage') or
-                    connection_details['entity']['datasource_type'] == 'bluemixcloudobjectstorage'):
+                else:
+                    cos_type = False
 
+            elif 'url' in connection_details:
                 cos_type = True
+                connection_details['entity'] = {'properties': connection_details}
 
             else:
                 cos_type = False
+            # --- end note
 
-        elif 'url' in connection_details:
-            cos_type = True
-            connection_details['entity'] = {'properties': connection_details}
+            if cos_type:
+                if 'cos_hmac_keys' in str(connection_details['entity']['properties']):
+                    creds = json.loads(connection_details['entity']['properties']['credentials'])
+                    connection_details['entity']['properties']['access_key'] = creds['cos_hmac_keys']['access_key_id']
+                    connection_details['entity']['properties']['secret_key'] = creds['cos_hmac_keys']['secret_access_key']
 
-        else:
-            cos_type = False
-        # --- end note
+                if self.connection is None:
+                    from .connections import S3Connection
+                    self.connection = S3Connection(
+                        endpoint_url=connection_details['entity']['properties'].get('url'),
+                        access_key_id=connection_details['entity']['properties'].get('access_key'),
+                        secret_access_key=connection_details['entity']['properties'].get('secret_key')
+                    )
 
-        if cos_type:
-            if 'cos_hmac_keys' in str(connection_details['entity']['properties']):
-                creds = json.loads(connection_details['entity']['properties']['credentials'])
-                connection_details['entity']['properties']['access_key'] = creds['cos_hmac_keys']['access_key_id']
-                connection_details['entity']['properties']['secret_key'] = creds['cos_hmac_keys']['secret_access_key']
+                else:
+                    self.connection.secret_access_key = connection_details['entity']['properties'].get('secret_key')
+                    self.connection.access_key_id = connection_details['entity']['properties'].get('access_key')
+                    self.connection.endpoint_url = connection_details['entity']['properties'].get('url')
 
-            if self.connection is None:
-                from .connections import S3Connection
-                self.connection = S3Connection(
-                    endpoint_url=connection_details['entity']['properties'].get('url'),
-                    access_key_id=connection_details['entity']['properties'].get('access_key'),
-                    secret_access_key=connection_details['entity']['properties'].get('secret_key')
-                )
+                if self.type == 'data_asset':
+                    try:
+                        self.location.bucket = attachment_details['connection_path'].split('/')[1]
+                        self.location.path = attachment_details['connection_path'].split('/')[2]
+
+                    except IndexError:
+                        self.location.bucket = connection_details['entity']['properties']['bucket']
+                        self.location.path = attachment_details['connection_path']
+
+                return True
 
             else:
-                self.connection.secret_access_key = connection_details['entity']['properties'].get('secret_key')
-                self.connection.access_key_id = connection_details['entity']['properties'].get('access_key')
-                self.connection.endpoint_url = connection_details['entity']['properties'].get('url')
+                return False
 
-            if self.type == 'data_asset':
-                try:
-                    self.location.bucket = attachment_details['connection_path'].split('/')[1]
-                    self.location.path = attachment_details['connection_path'].split('/')[2]
+        except Exception as e:
+            if os.environ.get('USER_ACCESS_TOKEN') is None:
+                raise e
 
-                except IndexError:
-                    self.location.bucket = connection_details['entity']['properties']['bucket']
-                    self.location.path = attachment_details['connection_path']
-
-            return True
-
-        else:
-            return False
+            else:
+                return False    # if we are in WS, ignore this check even if there was some error
 
     def _download_indices_from_cos(self, cos_client: 'resource', location_path) -> 'DataFrame':
         """Download indices for this connection. COS version"""
