@@ -368,7 +368,7 @@ class DataConnection(BaseDataConnection):
 
         elif self.type == DataConnectionTypes.DS:
             try:
-                if os.environ.get('USER_ACCESS_TOKEN') is None and self._check_if_connection_asset_is_s3():
+                if self._check_if_connection_asset_is_s3():
                     cos_client = self._init_cos_client()
                     data = self._download_indices_from_cos(cos_client=cos_client, location_path=holdout_data_indices_location)
                 else:
@@ -403,7 +403,7 @@ class DataConnection(BaseDataConnection):
 
         elif self.type == DataConnectionTypes.CA:
 
-            if os.environ.get('USER_ACCESS_TOKEN') is None and self._check_if_connection_asset_is_s3():
+            if self._check_if_connection_asset_is_s3():
                 cos_client = self._init_cos_client()
 
                 try:
@@ -530,7 +530,7 @@ class DataConnection(BaseDataConnection):
                 raise NotImplementedError("Multiple files for CP4D / WML Server is not yet supported.")
 
             try:
-                if os.environ.get('USER_ACCESS_TOKEN') is None and self._check_if_connection_asset_is_s3():
+                if self._check_if_connection_asset_is_s3():
                     cos_client = self._init_cos_client()
                     data = self._download_data_from_cos(cos_client=cos_client)
                 else:
@@ -566,7 +566,7 @@ class DataConnection(BaseDataConnection):
 
         elif self.type == DataConnectionTypes.CA:
 
-            if os.environ.get('USER_ACCESS_TOKEN') is None and self._check_if_connection_asset_is_s3():
+            if self._check_if_connection_asset_is_s3():
                 cos_client = self._init_cos_client()
 
                 try:
@@ -684,7 +684,7 @@ class DataConnection(BaseDataConnection):
                 raise TypeError("data should be either of type \"str\" or \"pandas.DataFrame\"")
 
         elif self.type == DataConnectionTypes.CA:
-            if os.environ.get('USER_ACCESS_TOKEN') is None and self._check_if_connection_asset_is_s3():
+            if self._check_if_connection_asset_is_s3():
                 cos_resource_client = self._init_cos_client()
                 if isinstance(data, str):
                     with open(data, "rb") as file_data:
@@ -916,7 +916,24 @@ class AssetLocation(BaseLocation):
         else:
             self.id = asset_id
 
-    def _get_connection_id(self, client) -> str:
+    def _get_bucket(self, client) -> str:
+        """Try to get bucket from data asset."""
+        connection_id = self._get_connection_id(client)
+        conn_details = client.connections.get_details(connection_id)
+        bucket = conn_details.get('entity', {}).get('properties', {}).get('bucket')
+
+        if bucket is None:
+            asset_details = client.data_assets.get_details(self.id)
+            connection_path = asset_details['entity'].get('folder_asset', {}).get('connection_path')
+            if connection_path is None:
+                attachment_content = self._get_attachment_details(client)
+                connection_path = attachment_content.get('connection_path')
+
+            bucket = connection_path.split('/')[1]
+
+        return bucket
+
+    def _get_attachment_details(self, client) -> dict:
         asset_details = client.data_assets.get_details(self.id)
 
         if 'attachment_id' in asset_details['metadata']:
@@ -939,7 +956,10 @@ class AssetLocation(BaseLocation):
         if attachment.status_code != 200:
             raise ApiRequestFailure(u"Failure during getting attachment details", attachment)
 
-        attachment_content = attachment.json()
+        return attachment.json()
+
+    def _get_connection_id(self, client) -> str:
+        attachment_content = self._get_attachment_details(client)
 
         if 'connection_id' in attachment_content:
             return attachment_content['connection_id']
@@ -1373,3 +1393,4 @@ class DatabaseLocation(BaseLocation):
 
     def _get_file_size(self) -> None:
         raise NotImplementedError()
+
