@@ -28,32 +28,6 @@ from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.generic_archive_
 from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.function_artifact import FunctionArtifact
 from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.hybrid_pipeline_model_artifact import HybridPipelineModelArtifact
 
-if lib_checker.installed_libs[PYSPARK]:
-    from .spark_pipeline_model_artifact import SparkPipelineModelArtifact
-    from .spark_pipeline_artifact import SparkPipelineArtifact
-    from pyspark.ml.pipeline import Pipeline, PipelineModel
-    from pyspark.sql import DataFrame
-
-if lib_checker.installed_libs[SCIKIT]:
-    from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.scikit_pipeline_model_artifact import ScikitPipelineModelArtifact
-    from sklearn.base import BaseEstimator
-
-if lib_checker.installed_libs[XGBOOST]:
-    import sys
-    import os
-    try:
-        sys.stderr = open(os.devnull, 'w')
-        import xgboost as xgb
-    except Exception as ex:
-        print ('Failed to import xgboost. Error: ' + str(ex))
-    finally:
-        sys.stderr.close()  # close /dev/null
-        sys.stderr = sys.__stderr__
-
-if lib_checker.installed_libs[TENSORFLOW]:
-    import tensorflow as tf
-    from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.tensorflow_pipeline_model_artifact import TensorflowPipelineModelArtifact, \
-        TensorflowPipelineModelTarArtifact
 def MLRepositoryArtifact(ml_artifact= None,
                          training_data=None,
                          training_dataref=None,
@@ -161,6 +135,8 @@ def MLRepositoryArtifact(ml_artifact= None,
         raise ValueError('Invalid type for meta_props: {}'.format(meta_props.__class__.__name__))
 
     if lib_checker.installed_libs[PYSPARK]:
+        from pyspark.ml.pipeline import Pipeline, PipelineModel
+        from pyspark.sql import DataFrame
         if ((training_data is not None and not isinstance(training_data, DataFrame)) and
                 issubclass(type(ml_artifact), Pipeline)):
             raise ValueError('Invalid type for training_data: {}'.format(training_data.__class__.__name__))
@@ -178,6 +154,7 @@ def MLRepositoryArtifact(ml_artifact= None,
                                        meta_props=meta_props)
 
     if lib_checker.installed_libs[SCIKIT]:
+        from sklearn.base import BaseEstimator
         if issubclass(type(ml_artifact), BaseEstimator):
             return _get_scikit_pipeline_model(ml_artifact,
                                               training_data,
@@ -187,6 +164,17 @@ def MLRepositoryArtifact(ml_artifact= None,
                                               name=name,
                                               meta_props=meta_props)
         if lib_checker.installed_libs[XGBOOST]:
+            import sys
+            import os
+            try:
+                sys.stderr = open(os.devnull, 'w')
+                import xgboost as xgb
+            except Exception as ex:
+                print('Failed to import xgboost. Error: ' + str(ex))
+            finally:
+                sys.stderr.close()  # close /dev/null
+                sys.stderr = sys.__stderr__
+
             if isinstance(ml_artifact, xgb.Booster):
                 return _get_xgboost_model(ml_artifact,
                                           training_data,
@@ -205,6 +193,7 @@ def MLRepositoryArtifact(ml_artifact= None,
                                        name=name, meta_props=meta_props)
 
     if lib_checker.installed_libs[TENSORFLOW]:
+        import tensorflow as tf
         import sys
         if sys.version_info < (3, 7) and \
                 (('2.1.0' in tf.__version__ and isinstance(ml_artifact,tf.compat.v1.Session) or
@@ -292,6 +281,7 @@ def MLRepositoryArtifact(ml_artifact= None,
 
 
 def _get_pipeline(pipeline, name, meta_props):
+    from .spark_pipeline_artifact import SparkPipelineArtifact
     return SparkPipelineArtifact(pipeline, name=name, meta_props=meta_props)
 
 def _get_experiment_artifact(meta_props):
@@ -301,11 +291,13 @@ def _get_hybrid_pipeline_model_artifact(name, meta_props):
     return HybridPipelineModelArtifact(name=name, meta_props=meta_props)
 
 def _get_pipeline_model(pipeline_model, training_data, pipeline_artifact, name, meta_props):
+    from .spark_pipeline_model_artifact import SparkPipelineModelArtifact
     return SparkPipelineModelArtifact(pipeline_model, training_data=training_data, pipeline_artifact=pipeline_artifact, name=name, meta_props=meta_props)
 
 
 def _get_scikit_pipeline_model(scikit_pipeline_model, training_features, training_target, feature_names,
                                label_column_names, name, meta_props):
+    from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.scikit_pipeline_model_artifact import ScikitPipelineModelArtifact
     return ScikitPipelineModelArtifact(scikit_pipeline_model,
                                        training_features,
                                        training_target,
@@ -317,6 +309,7 @@ def _get_scikit_pipeline_model(scikit_pipeline_model, training_features, trainin
 
 def _get_xgboost_model(xgboost_model, training_features, training_target, feature_names,
                        label_column_names, name, meta_props):
+    from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.scikit_pipeline_model_artifact import ScikitPipelineModelArtifact
     return ScikitPipelineModelArtifact(xgboost_model,
                                        training_features,
                                        training_target,
@@ -327,6 +320,7 @@ def _get_xgboost_model(xgboost_model, training_features, training_target, featur
 
 
 def _get_tensorflow_model(tensorflow_model, name, meta_props,signature_def_map,tags,assets_collection,legacy_init_op,clear_devices,main_op):
+    from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.tensorflow_pipeline_model_artifact import TensorflowPipelineModelArtifact
     return TensorflowPipelineModelArtifact(tensorflow_model,
                                       name=name,
                                       meta_props=meta_props,
@@ -339,6 +333,7 @@ def _get_tensorflow_model(tensorflow_model, name, meta_props,signature_def_map,t
 
 
 def _get_tensorflow_model_tar(tf_tar_artifact, name, meta_props):
+    from ibm_watson_machine_learning.libs.repo.mlrepositoryartifact.tensorflow_pipeline_model_artifact import TensorflowPipelineModelTarArtifact
     return TensorflowPipelineModelTarArtifact(tf_tar_artifact,
                                               name=name,
                                               meta_props=meta_props)
