@@ -248,7 +248,7 @@ class ExperimentCollection:
 
                 r = self.repository_api.v3_libraries_create(library_input)
                 statuscode = r[1]
-                if statuscode is not 201:
+                if statuscode != 201:
                     logger.info('Error while creating library: no location header')
                     raise ApiException(404, 'No artifact location')
 
