@@ -122,7 +122,7 @@ class LibrariesCollection:
         libraries_patch_output = self.repository_api.v3_libraries_patch_with_http_info(libraries_patch_input, libraries_id)
         statuscode = libraries_patch_output[1]
 
-        if statuscode is not 200:
+        if statuscode != 200:
             logger.info('Error while patching libraries: no location header')
             raise ApiException(statuscode,"Error while patching libraries")
 
@@ -159,7 +159,7 @@ class LibrariesCollection:
                 raise IOError('The artifact specified ( {} ) does not exist.'.format(artifact.library))
 
         statuscode = library_output[1]
-        if statuscode is not 201:
+        if statuscode != 201:
             logger.info('Error while creating libraries: no location header')
             raise ApiException(statuscode, 'No artifact location')
 
