@@ -127,7 +127,7 @@ class WmlExperimentCollection:
         experiment_patch_output = self.repository_api.v3_experiments_id_patch_with_http_info(experiment_id, experiment_patch_input)
         statuscode = experiment_patch_output[1]
 
-        if statuscode is not 200:
+        if statuscode != 200:
             logger.info('Error while patching experiment: no location header')
             raise ApiException(statuscode,"Error while patching experiment")
 
@@ -153,7 +153,7 @@ class WmlExperimentCollection:
 
 
         statuscode = experiment_output[1]
-        if statuscode is not 201:
+        if statuscode != 201:
             logger.info('Error while creating experiment: no location header')
             raise ApiException(statuscode, 'No artifact location')
 
