@@ -173,10 +173,10 @@ class Runtimes(WMLResource):
 
         try:
             if not self._ICP:
-                response_post = requests.post(self._href_definitions.get_custom_libraries_href(), json=lib_metadata,
+                response_post = requests.post(self._client.service_instance._href_definitions.get_custom_libraries_href(), json=lib_metadata,
                                               headers=self._client._get_headers())
             else:
-                response_post = requests.post(self._href_definitions.get_custom_libraries_href(), json=lib_metadata,
+                response_post = requests.post(self._client.service_instance._href_definitions.get_custom_libraries_href(), json=lib_metadata,
                                               headers=self._client._get_headers(), verify=False)
             details = self._handle_response(201, u'saving libraries', response_post)
 
@@ -239,10 +239,10 @@ class Runtimes(WMLResource):
 
         try:
             if not self._ICP:
-                response_post = requests.post(self._href_definitions.get_runtimes_href(), json=metadata,
+                response_post = requests.post(self._client.service_instance._href_definitions.get_runtimes_href(), json=metadata,
                                               headers=self._client._get_headers())
             else:
-                response_post = requests.post(self._href_definitions.get_runtimes_href(), json=metadata,
+                response_post = requests.post(self._client.service_instance._href_definitions.get_runtimes_href(), json=metadata,
                                               headers=self._client._get_headers(), verify=False)
             details = self._handle_response(201, u'saving runtimes', response_post)
             if self.ConfigurationMetaNames.CONFIGURATION_FILEPATH in meta_props:
@@ -377,7 +377,7 @@ class Runtimes(WMLResource):
         # if runtime_uid is not None and not is_uid(runtime_uid):
         #     raise WMLClientError(u'\'runtime_uid\' is not an uid: \'{}\''.format(runtime_uid))
 
-        url = self._href_definitions.get_runtimes_href()
+        url = self._client.service_instance._href_definitions.get_runtimes_href()
         if runtime_uid is not None or self._client.default_project_id is not None:
          return self._get_no_space_artifact_details(url, runtime_uid, limit, 'runtime specs', pre_defined="True")
         if pre_defined:
@@ -423,7 +423,7 @@ class Runtimes(WMLResource):
         if library_uid is not None and not is_uid(library_uid):
             raise WMLClientError(u'\'library_uid\' is not an uid: \'{}\''.format(library_uid))
 
-        url = self._href_definitions.get_custom_libraries_href()
+        url = self._client.service_instance._href_definitions.get_custom_libraries_href()
         if library_uid is not None or self._client.default_project_id is not None:
             return self._get_no_space_artifact_details(url, library_uid, limit, 'libraries')
         return self._get_artifact_details(url, library_uid, limit, 'libraries')
@@ -618,7 +618,7 @@ class Runtimes(WMLResource):
         if with_libraries:
             runtime_details = self.get_details(runtime_uid)
 
-        url = self._href_definitions.get_runtime_href(runtime_uid)
+        url = self._client.service_instance._href_definitions.get_runtime_href(runtime_uid)
 
         if not self._ICP:
             response_delete = requests.delete(
@@ -662,7 +662,7 @@ class Runtimes(WMLResource):
             lib_uid = lib['metadata']['guid']
             if len(self._get_runtimes_uids_for_lib(lib_uid, details)) == 0:
                 print('Deleting orphaned \'{}\' library... '.format(lib_uid), end="")
-                library_endpoint = self._href_definitions.get_custom_library_href(lib_uid)
+                library_endpoint = self._client.service_instance._href_definitions.get_custom_library_href(lib_uid)
                 if not self._ICP:
                     response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
                 else:
@@ -701,7 +701,7 @@ class Runtimes(WMLResource):
             print("WARNING!! 'runtimes' is DEPRECATED. Use 'software_specifications' instead to create and manage runtimes/specifications" )
 
         Runtimes._validate_type(library_uid, u'library_uid', STR_TYPE, True)
-        library_endpoint = self._href_definitions.get_custom_library_href(library_uid)
+        library_endpoint = self._client.service_instance._href_definitions.get_custom_library_href(library_uid)
         if not self._ICP:
             response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
         else:
@@ -866,7 +866,7 @@ class Runtimes(WMLResource):
         if not is_uid(runtime_uid):
             raise WMLClientError(u'\'runtime_uid\' is not an uid: \'{}\''.format(runtime_uid))
 
-        download_url = self._href_definitions.get_runtime_href(runtime_uid) + '/content'
+        download_url = self._client.service_instance._href_definitions.get_runtime_href(runtime_uid) + '/content'
 
         if not self._ICP:
             response_get = requests.get(
@@ -934,7 +934,7 @@ class Runtimes(WMLResource):
         if not is_uid(library_uid):
             raise WMLClientError(u'\'library_uid\' is not an uid: \'{}\''.format(library_uid))
 
-        download_url = self._href_definitions.get_custom_library_href(library_uid) + '/content'
+        download_url = self._client.service_instance._href_definitions.get_custom_library_href(library_uid) + '/content'
 
         if not self._ICP:
             response_get = requests.get(
@@ -999,7 +999,7 @@ class Runtimes(WMLResource):
 
         patch_payload = self.LibraryMetaNames._generate_patch_payload(details['entity'], changes, with_validation=True)
 
-        url = self._href_definitions.get_custom_library_href(library_uid)
+        url = self._client.service_instance._href_definitions.get_custom_library_href(library_uid)
         if not self._ICP:
             response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
         else:
@@ -1047,7 +1047,7 @@ class Runtimes(WMLResource):
 
         patch_payload = self.LibraryMetaNames._generate_patch_payload(details['entity'], changes, with_validation=True)
 
-        url = self._href_definitions.get_runtime_href(runtime_uid)
+        url = self._client.service_instance._href_definitions.get_runtime_href(runtime_uid)
         if not self._ICP:
             response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
         else:
@@ -1113,7 +1113,7 @@ class Runtimes(WMLResource):
         if rev is not None:
             clone_meta["rev"] = rev
 
-        url = self._href_definitions.get_runtime_href(runtime_uid)
+        url = self._client.service_instance._href_definitions.get_runtime_href(runtime_uid)
         if not self._ICP:
             response_post = requests.post(url, json=clone_meta,
                                               headers=self._client._get_headers())
@@ -1182,7 +1182,7 @@ class Runtimes(WMLResource):
         if rev is not None:
             clone_meta["rev"] = rev
 
-        url = self._href_definitions.get_custom_library_href(library_uid)
+        url = self._client.service_instance._href_definitions.get_custom_library_href(library_uid)
         if not self._ICP:
             response_post = requests.post(url, json=clone_meta,
                                               headers=self._client._get_headers())
