@@ -1,5 +1,5 @@
 import unittest
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 from ibm_watson_machine_learning.spaces import Spaces
 from ibm_watson_machine_learning.tests.Cloud.preparation_and_cleaning import *
 import uuid
@@ -11,7 +11,7 @@ class TestWMLClientWithPlatformSpace(unittest.TestCase):
     member_uid = None
     member_href = None
 
-    logger = get_logger(__name__)
+    logger = logging.getLogger(__name__)
 
     @classmethod
     def setUpClass(self):
