@@ -14,7 +14,7 @@ from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoP
 from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, get_space_id,
                                                      is_cp4d)
 from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
-from ibm_watson_machine_learning.utils.autoai.enums import TShirtSize
+from ibm_watson_machine_learning.utils.autoai.enums import TShirtSize, SamplingTypes
 
 
 class AbstractTestAutoAIRemote(abc.ABC):
@@ -52,6 +52,7 @@ class AbstractTestAutoAIRemote(abc.ABC):
 
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-qa")
     pod_version = environ.get('KB_VERSION', None)
+    space_name = environ.get('SPACE_NAME', 'regression_tests_sdk_space')
 
     cos_endpoint = "https://s3.us-south.cloud-object-storage.appdomain.cloud"
     data_cos_path = 'iris_dataset.csv'
@@ -74,8 +75,6 @@ class AbstractTestAutoAIRemote(abc.ABC):
     project_id = None
     space_id = None
 
-    space_name = 'autoai_tests_sdk_space'
-
     asset_id = None
     connection_id = None
 
@@ -126,7 +125,8 @@ class AbstractTestAutoAIRemote(abc.ABC):
             max_number_of_estimators=1,
             csv_separator=self.custom_separator,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
-            autoai_pod_version=self.pod_version
+            autoai_pod_version=self.pod_version,
+            n_parallel_data_connections=4,
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
