@@ -56,6 +56,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-qa")
     pod_version = environ.get('KB_VERSION', None)
+    space_name = environ.get('SPACE_NAME', 'regression_tests_sdk_space')
 
     data_connection = None
     results_connection = None
@@ -86,8 +87,6 @@ class TestAutoAIRemote(unittest.TestCase):
     project_id = None
     space_id = None
 
-    space_name = 'autoai_tests_sdk_space'
-
     asset_id = None
 
     @classmethod
