@@ -4,6 +4,7 @@ from pprint import pprint
 import pandas as pd
 import traceback
 from os import environ
+import uuid
 
 from ibm_watson_machine_learning import APIClient
 
@@ -44,6 +45,9 @@ class TestAutoAIRemote(unittest.TestCase):
     pipeline_opt: 'RemoteAutoPipelines' = None
     service: 'WebService' = None
     service_batch: 'Batch' = None
+    deployment_serving_name = 'depl_serving_name_' + str(uuid.uuid4())[:8]
+    deployment_serving_name_patch = 'depl_serving_name_patch_' + str(uuid.uuid4())[:8]
+    deployment_uid = None
 
     data_location = './autoai/data/breast_cancer.csv'
 
@@ -184,9 +188,9 @@ class TestAutoAIRemote(unittest.TestCase):
             test_size=0.1,
             max_number_of_estimators=1,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
-            autoai_pod_version='!>dev-12-holdout-indices',
-            return_holdout_indices=True,
-            retrain_on_holdout=False
+            # autoai_pod_version='!>dev-12-holdout-indices',
+            # return_holdout_indices=True,
+            # retrain_on_holdout=False
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -365,7 +369,7 @@ class TestAutoAIRemote(unittest.TestCase):
         res = self.service.create(
             experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
             model="Pipeline_1",
-            serving_name="test_deployment",
+            serving_name=self.deployment_serving_name,
             deployment_name=self.DEPLOYMENT_NAME)
 
         self.assertIsNotNone(self.service.id, msg="Online Deployment creation - missing id")
@@ -375,8 +379,26 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_22b_serving_name_test(self):
         self.wml_client.set.default_space(self.space_id)
-        deployment_details = self.wml_client.deployments.get_details(serving_name='test_deployment')
-        self.wml_client.deployments.get_serving_href(deployment_details)
+        
+        deployment_details = self.wml_client.deployments.get_details(serving_name='non_existing')
+        self.assertTrue(len(deployment_details['resources']) == 0)
+
+        deployment_details = self.wml_client.deployments.get_details(serving_name=self.deployment_serving_name)
+        self.assertTrue(len(deployment_details['resources']) == 1)
+
+        self.assertTrue(str(self.wml_client.deployments.get_serving_href(deployment_details['resources'][0])).endswith(
+            f'/{self.deployment_serving_name}/predictions'))
+
+        self.wml_client.deployments.update(self.service.id, {'serving_name': self.deployment_serving_name_patch})
+
+        deployment_details = self.wml_client.deployments.get_details(serving_name=self.deployment_serving_name)
+        self.assertTrue(len(deployment_details['resources']) == 0)
+
+        deployment_details = self.wml_client.deployments.get_details(serving_name=self.deployment_serving_name_patch)
+        self.assertTrue(len(deployment_details['resources']) == 1)
+
+        self.assertTrue(str(self.wml_client.deployments.get_serving_href(deployment_details['resources'][0])).endswith(
+            f'/{self.deployment_serving_name_patch}/predictions'))
 
     def test_23_score_deployed_model(self):
         nb_records = 5
