@@ -1,6 +1,7 @@
 import unittest
 from os import environ
 import time
+import uuid
 
 
 import traceback
@@ -98,6 +99,9 @@ class TestAutoAIRemote(unittest.TestCase):
     space_id = None
     asset_id = None
 
+    deployment_serving_name = 'depl_serving_name_' + str(uuid.uuid4())[:8]
+    deployment_serving_name_patch = 'depl_serving_name_patch_' + str(uuid.uuid4())[:8]
+
     
 
     @classmethod
@@ -267,7 +271,9 @@ class TestAutoAIRemote(unittest.TestCase):
         print(f"Run status = {self.remote_auto_pipelines.get_run_status()}")
         # note: check if first pipeline was generated
 
-        metrics = self.wml_client.training.get_details(self.run_id)['entity']['status'].get('metrics', [])
+        training_details = self.wml_client.training.get_details(self.run_id)
+        metrics = training_details['entity']['status'].get('metrics', [])
+
         while chose_model_output("1") not in str(metrics) and self.remote_auto_pipelines.get_run_status() not in ['failed', 'canceled']:
             time.sleep(5)
             print(".", end=" ")
@@ -409,6 +415,32 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(self.service.scoring_url,
                              msg="Online Deployment creation - mscoring url  missing")
 
+    def test_21b_serving_name_test(self):
+        self.wml_client.set.default_space(self.space_id)
+
+        deployment_details = self.wml_client.deployments.get_details(serving_name='non_existing')
+        self.assertTrue(len(deployment_details['resources']) == 0)
+
+        self.wml_client.deployments.update(self.service.deployment_id, {
+            self.wml_client.deployments.ConfigurationMetaNames.SERVING_NAME: self.deployment_serving_name})
+
+        deployment_details = self.wml_client.deployments.get_details(serving_name=self.deployment_serving_name)
+        self.assertTrue(len(deployment_details['resources']) == 1)
+
+        self.assertTrue(str(self.wml_client.deployments.get_serving_href(deployment_details['resources'][0])).endswith(
+            f'/{self.deployment_serving_name}/predictions'))
+
+        self.wml_client.deployments.update(self.service.deployment_id, {'serving_name': self.deployment_serving_name_patch})
+
+        deployment_details = self.wml_client.deployments.get_details(serving_name=self.deployment_serving_name)
+        self.assertTrue(len(deployment_details['resources']) == 0)
+
+        deployment_details = self.wml_client.deployments.get_details(serving_name=self.deployment_serving_name_patch)
+        self.assertTrue(len(deployment_details['resources']) == 1)
+
+        self.assertTrue(str(self.wml_client.deployments.get_serving_href(deployment_details['resources'][0])).endswith(
+            f'/{self.deployment_serving_name_patch}/predictions'))
+
     def test_22_score_deployed_model(self):
         nb_records = 5
         predictions = self.service.score(payload=self.train_data.drop([self.prediction_column], axis=1)[:nb_records])
