@@ -69,11 +69,13 @@ class TestAutoAIRemote(unittest.TestCase):
         bucket_name = "wml-autoaitests-qa"
 
     pod_version = environ.get('KB_VERSION', None)
+    space_name = environ.get('SPACE_NAME', 'regression_tests_sdk_space')
 
     data_cos_path = 'data/credit_risk_training_light.csv'
     cos_resource_instance_id = None
 
     results_cos_path = 'results_wml_autoai'
+    batch_payload_filename = 'batch_payload_credit_risk.csv'
 
     best_pipeline: 'Pipeline' = None
     deployed_pipeline = None
@@ -81,8 +83,6 @@ class TestAutoAIRemote(unittest.TestCase):
     OPTIMIZER_NAME = 'CreditRisk binary as sample notebook test'
     DEPLOYMENT_NAME = "CreditRisk AutoAI test Deployment "
 
-    space_name = 'autoai_tests_sdk_space'
-
     space_id = None
     project_id = None
 
@@ -455,15 +455,10 @@ class TestAutoAIRemote(unittest.TestCase):
 
     @unittest.skipIf(is_cp4d(), "SnapML is not supported on CPD")
     def test_30_batch_deployment_setup_and_preparation(self):
-        if self.wml_client.ICP:
-            TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
-                                                   source_project_id=self.project_id,
-                                                   target_wml_credentials=self.wml_credentials,
-                                                   target_space_id=self.space_id)
-        else:
-            TestAutoAIRemote.service_batch = Batch(self.wml_credentials,
-                                                   source_space_id=self.space_id)
-
+        TestAutoAIRemote.service_batch = Batch(source_wml_credentials=self.wml_credentials.copy(),
+                                               source_project_id=self.project_id,
+                                               target_wml_credentials=self.wml_credentials,
+                                               target_space_id=self.space_id)
         self.assertIsInstance(self.service_batch, Batch, msg="Deployment is not of Batch type.")
         self.assertIsInstance(self.service_batch._source_workspace, WorkSpace, msg="Workspace set incorrectly.")
         self.assertEqual(self.service_batch.id, None, msg="Deployment ID initialized incorrectly")
@@ -485,8 +480,8 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_33a_run_job_batch_deployed_model_with_data_connection_data_asset(self):
         self.wml_client.set.default_space(self.space_id) if self.wml_client.ICP else None
         asset_details = self.wml_client.data_assets.create(
-            name=self.batch_payload_location.split('/')[-1],
-            file_path=self.batch_payload_location)
+            name=self.data_location.split('/')[-1],
+            file_path=self.data_location)
         asset_id = asset_details['metadata']['guid']
         asset_href = self.wml_client.data_assets.get_href(asset_details)
 
@@ -515,7 +510,7 @@ class TestAutoAIRemote(unittest.TestCase):
                                         access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
                                         secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
                 location=S3Location(bucket=self.bucket_name,
-                                    path=self.batch_payload_location.split('/')[-1])
+                                    path=self.batch_payload_filename)
             )
             results_reference = DataConnection(
                 connection=S3Connection(endpoint_url=self.cos_endpoint,
@@ -524,8 +519,8 @@ class TestAutoAIRemote(unittest.TestCase):
                 location=S3Location(bucket=self.bucket_name,
                                     path='batch_output_car-price.csv')
             )
-            payload_reference.write(data=self.batch_payload_location,
-                                    remote_name=self.batch_payload_location.split('/')[-1])
+            payload_reference.write(data=self.X,
+                                    remote_name=self.batch_payload_filename)
 
         scoring_params = self.service_batch.run_job(
             payload=[payload_reference],
