@@ -73,6 +73,7 @@ class TestAutoAIRemote(unittest.TestCase):
         bucket_name = "wml-autoaitests-qa"
 
     pod_version = environ.get('KB_VERSION', None)
+    space_name = environ.get('SPACE_NAME', 'regression_tests_sdk_space')
 
     data_cos_path = 'data/drug_train_data_updated.csv'
     cos_resource_instance_id = None
@@ -93,8 +94,6 @@ class TestAutoAIRemote(unittest.TestCase):
     OPTIMIZER_NAME = 'Drug Data AutoAI with fairness SDK test'
     DEPLOYMENT_NAME = "Drug Data AutoAI with fairness SDK test Deployment "
 
-    space_name = 'tests_sdk_space'
-
     space_id = None
     project_id = None
 
