@@ -65,6 +65,7 @@ class TestAutoAIRemote(unittest.TestCase):
     # CLOUD CONNECTION DETAILS:
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-qa")
     pod_version = environ.get('KB_VERSION', None)
+    space_name = environ.get('SPACE_NAME', 'regression_tests_sdk_space')
 
     cos_endpoint = "https://s3.us-south.cloud-object-storage.appdomain.cloud"
     data_cos_path = 'data/credit_risk_insurance__two_sheets.xlsx'
@@ -72,8 +73,6 @@ class TestAutoAIRemote(unittest.TestCase):
 
     results_cos_path = 'results_wml_autoai'
 
-    space_name = 'autoai_tests_sdk_space'
-
     OPTIMIZER_NAME = 'Insurance wml_autoai regression test'
     DEPLOYMENT_NAME = "Insurance AutoAI Deployment tests"
 
