@@ -60,6 +60,7 @@ class TestOBMOnly(unittest.TestCase):
     train_data = None
     holdout_data = None
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-obm-qa")
+    space_name = environ.get('SPACE_NAME', 'regression_tests_sdk_space')
 
     cos_endpoint =  "https://s3.us-south.cloud-object-storage.appdomain.cloud"
     cos_resource_instance_id = None
@@ -77,8 +78,6 @@ class TestOBMOnly(unittest.TestCase):
     OPTIMIZER_NAME = 'OBM only test'
     DEPLOYMENT_NAME = "OBM only deployment test"
 
-    space_name = 'autoai_tests_sdk_space'
-
     job_id = None
 
     # # CP4D CONNECTION DETAILS:
