@@ -69,6 +69,7 @@ class TestOBMAndKB(unittest.TestCase):
     holdout_data = None
 
     bucket_name = environ.get('BUCKET_NAME', "wml-autoaitests-obm-qa")
+    space_name = environ.get('SPACE_NAME', 'regression_tests_sdk_space')
 
     cos_endpoint = "https://s3.us-south.cloud-object-storage.appdomain.cloud"
     cos_resource_instance_id = None
@@ -86,8 +87,6 @@ class TestOBMAndKB(unittest.TestCase):
     OPTIMIZER_NAME = 'OBM + KB test'
     DEPLOYMENT_NAME = "OBM + KB deployment test"
 
-    space_name = 'autoai_tests_sdk_space'
-
     job_id = None
 
 
