@@ -31,7 +31,8 @@ __all__ = [
     "TShirtSize",
     "MetricsToDirections",
     'PositiveLabelClass',
-    'VisualizationTypes'
+    'VisualizationTypes',
+    'SamplingTypes'
 ]
 
 
@@ -46,7 +47,7 @@ class ClassificationAlgorithms(Enum):
     DT = "DecisionTreeClassifierEstimator"
     SnapDT = "SnapDecisionTreeClassifier"
     SnapRF = "SnapRandomForestClassifier"
-    SnapSVM = "SnapSVMClassifier",
+    SnapSVM = "SnapSVMClassifier"
     SnapLR = "SnapLogisticRegression"
 
 
@@ -289,3 +290,9 @@ class VisualizationTypes:
     """Types of visualization options."""
     PDF = 'pdf'
     INPLACE = 'inplace'
+
+
+class SamplingTypes:
+    """Types of training data sampling"""
+    FIRST_N_RECORDS = 'first_n_records'
+    RANDOM_STRATIFIED = 'random_stratified'
